@@ -156,12 +156,7 @@ aris_proof_init ()
 {
   aris_proof * ap;
   ap = (aris_proof *) calloc (1, sizeof (aris_proof));
-  if (!ap)
-    {
-      REPORT ();
-      perror (NULL);
-      return NULL;
-    }
+  CHECK_ALLOC (ap, NULL);
 
   ap->vars = init_list ();
   if (!ap->vars)
@@ -238,7 +233,7 @@ aris_proof_post_init (aris_proof * ap)
   // Initialize the separator
   SEN_PARENT (ap)->separator = gtk_hseparator_new ();
 
-  sd = sen_data_init (-1, -1, NULL, NULL, 1, NULL, 0, 0);
+  sd = SEN_DATA_DEFAULT (1, 0, 0);
   if (!sd)
     return -1;
 
@@ -273,12 +268,7 @@ aris_proof_init_from_proof (proof_t * proof)
 {
   aris_proof * ap;
   ap = (aris_proof *) calloc (1, sizeof (aris_proof));
-  if (!ap)
-    {
-      REPORT ();
-      perror (NULL);
-      return NULL;
-    }
+  CHECK_ALLOC (ap, NULL);
 
   ap->vars = init_list ();
   if (!ap->vars)
@@ -462,12 +452,7 @@ aris_proof_set_changed (aris_proof * ap, int changed)
   int pos = 0;
 
   new_title = (char *) calloc (strlen (title) + 4, sizeof (char));
-  if (!new_title)
-    {
-      REPORT ();
-      perror (NULL);
-      return -1;
-    }
+  CHECK_ALLOC (new_title, -1);
   pos = sprintf (new_title, "%s", title);
   if (changed && !ap->edited)
     {
@@ -648,7 +633,7 @@ aris_proof_create_new_prem (aris_proof * ap)
   sentence * sen;
   sen_data * sd;
 
-  sd = sen_data_init (-1, -1, NULL, NULL, 1, NULL, 0, 0);
+  sd = SEN_DATA_DEFAULT (1, 0, 0);
   if (!sd)
     return NULL;
 
@@ -673,7 +658,7 @@ aris_proof_create_new_conc (aris_proof * ap)
   sentence * sen;
   sen_data * sd;
 
-  sd = sen_data_init (-1, -1, NULL, NULL, 0, NULL, 0, 0);
+  sd = SEN_DATA_DEFAULT (0, 0, 0);
   if (!sd)
     return NULL;
 
@@ -698,7 +683,7 @@ aris_proof_create_new_sub (aris_proof * ap)
   sentence * sen;
   sen_data * sd;
 
-  sd = sen_data_init (-1, -1, NULL, NULL, 0, NULL, 1, 0);
+  sd = SEN_DATA_DEFAULT (0, 1, 0);
   if (!sd)
     return NULL;
 
@@ -726,7 +711,7 @@ aris_proof_end_sub (aris_proof * ap)
   sentence * sen;
   sen_data * sd;
 
-  sd = sen_data_init (-1, -1, NULL, NULL, 0, NULL, 0, -1);
+  sd = SEN_DATA_DEFAULT (0, 0, -1);
   if (!sd)
     return NULL;
 
@@ -804,11 +789,7 @@ aris_proof_set_filename (aris_proof * ap, const char * filename)
   char * new_title, * base_name;
 
   new_title = (char *) calloc (strlen (filename) + 12, sizeof (char));
-  if (!new_title)
-    {
-      perror (NULL);
-      return -1;
-    }
+  CHECK_ALLOC (new_title, -1);
   ap->cur_file = (char *) filename;
 
   GFile * file = g_file_new_for_path (filename);
